==> openwebbeans-1.7.6-source-release.zip: openwebbeans-1.7.6/webbeans-web/src/test/java/org/apache/webbeans/web/tests/initialization/MySessionHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.web.tests.initialization;

import javax.annotation.PostConstruct;
import javax.enterprise.context.Initialized;
import javax.enterprise.context.RequestScoped;
import javax.enterprise.context.SessionScoped;
import javax.enterprise.event.Observes;
import javax.enterprise.inject.Produces;
import javax.inject.Inject;
import javax.servlet.http.HttpSession;

@RequestScoped
public class MySessionHandler
{
    @Produces
    @SessionScoped
    public MySession produce()
    {
        return new MySession();
    }

    @Inject
    private MySession session;

    private boolean initialized;
    
    @PostConstruct
    public void init()
    {
        initialized = false;
    }
    
    public void init(@Observes @Initialized(SessionScoped.class) HttpSession httpSession)
            throws Exception
    {
        session.toString();
        
        initialized = true;
    }

    public boolean isInitialized()
    {
        return initialized;
    }
}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-web/src/test/java/org/apache/webbeans/web/tests/initialization/MySessionHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.web.tests.initialization;

import jakarta.annotation.PostConstruct;
import jakarta.enterprise.context.Initialized;
import jakarta.enterprise.context.RequestScoped;
import jakarta.enterprise.context.SessionScoped;
import jakarta.enterprise.event.Observes;
import jakarta.enterprise.inject.Produces;
import jakarta.inject.Inject;
import jakarta.servlet.http.HttpSession;

@RequestScoped
public class MySessionHandler
{
    @Produces
    @SessionScoped
    public MySession produce()
    {
        return new MySession();
    }

    @Inject
    private MySession session;

    private boolean initialized;
    
    @PostConstruct
    public void init()
    {
        initialized = false;
    }
    
    public void init(@Observes @Initialized(SessionScoped.class) HttpSession httpSession)
            throws Exception
    {
        session.toString();
        
        initialized = true;
    }

    public boolean isInitialized()
    {
        return initialized;
    }
}
